
.. py:currentmodule:: pythreejs

TextTexture
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: TextTexture(string='', )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.Texture`.

    Three.js docs: https://threejs.org/docs/#api/textures/TextTexture


    .. py:attribute:: color

        .. sourcecode:: python

            Unicode("white", allow_none=False).tag(sync=True)

    .. py:attribute:: fontFace

        .. sourcecode:: python

            Unicode("Arial", allow_none=False).tag(sync=True)

    .. py:attribute:: size

        .. sourcecode:: python

            CInt(12, allow_none=False).tag(sync=True)

    .. py:attribute:: string

        .. sourcecode:: python

            Unicode('', allow_none=False).tag(sync=True)

    .. py:attribute:: squareTexture

        .. sourcecode:: python

            Bool(True, allow_none=False).tag(sync=True)

